@@ -9,20 +9,18 @@ test_that("adjust_p return the correct class", {
     tidy_summary(prtest = "P") %>%
     adjust_p()
 
-  expect_is(adj, "tidy_summary")
+  expect_s3_class(adj, "tidy_summary")
 })
 
 test_that("warning and return if test is not set", {
   skip_on_cran()
 
-  expect_warning(
-    no_test_adj <- Hmisc:::summary.formula(Species ~ .,
-      data = iris,
-      method = "reverse"
-    ) %>%
-      tidy_summary() %>%
-      adjust_p()
-  )
+  no_test_adj <- Hmisc:::summary.formula(Species ~ .,
+    data = iris,
+    method = "reverse"
+  ) %>%
+    tidy_summary() %>%
+    adjust_p()
 
-  expect_is(no_test_adj, "tidy_summary")
+  expect_s3_class(no_test_adj, "tidy_summary")
 })
