@@ -1,8 +1,6 @@
-context("test-install_pkg_set")
-
 test_that("empty please_install()", {
 
-  expect_null(please_install(character(0)))
+  expect_null(please_install(character(0L)))
 
   if (!interactive()) {
     expect_error(please_install("stats"),
