@@ -3,7 +3,7 @@ test_that("single check works", {
 
   test_desc <- Hmisc::describe(mtcars)
   expect_false(is_single_hdesc(test_desc))
-  expect_true(is_single_hdesc(test_desc[[1]]))
+  expect_true(is_single_hdesc(test_desc[[1L]]))
   expect_false(is_single_hdesc(mtcars))
 })
 
@@ -13,7 +13,7 @@ test_that("original check works", {
 
   test_desc <- Hmisc::describe(mtcars)
   expect_true(is_hdesc(test_desc))
-  expect_true(is_hdesc(test_desc[[1]]))
+  expect_true(is_hdesc(test_desc[[1L]]))
   expect_false(is_hdesc(mtcars))
 })
 
@@ -25,7 +25,7 @@ test_that("cat check works", {
   expect_true(is_hcat(test_desc[["vs"]]))
   expect_false(is_hcat(test_desc[["mpg"]]))
 
-  skip_if(as.integer(R.Version()$major) < 4)
+  skip_if(as.integer(R.Version()[["major"]]) < 4L)
   expect_error(is_hcat(test_desc), "must be a single|is not TRUE")
 })
 
@@ -40,10 +40,10 @@ test_that("original check works", {
   test_nunique <- Hmisc::describe(airquality)
   expect_false(is_hcon(test_nunique[["Month"]]))
   expect_true(
-    is_hcon(test_nunique[["Month"]], n_unique = 4)
+    is_hcon(test_nunique[["Month"]], n_unique = 4L)
   )
 
-  skip_if(as.integer(R.Version()$major) < 4)
+  skip_if(as.integer(R.Version()[["major"]]) < 4L)
   expect_error(is_hcon(test_desc), "must be a single|is not TRUE")
 })
 
@@ -56,11 +56,11 @@ test_that("htype works", {
   expect_equal(htype(test_desc[["mpg"]]), "con")
   expect_equal(htype(test_desc[["carb"]]), "none")
   expect_equal(
-    htype(test_desc[["carb"]], n_unique = 4),
+    htype(test_desc[["carb"]], n_unique = 4L),
     "con"
   )
 
-  skip_if(as.integer(R.Version()$major) < 4)
+  skip_if(as.integer(R.Version()[["major"]]) < 4L)
   expect_error(htype(test_desc), "must be a single|is not TRUE")
 })
 
